@@ -61,17 +61,14 @@ class BaseAdaptor(object):
 
                         # fire before_change
                         failed = False
-                        parameters_replacement = {}
+                        additional_parameters = {}
                         if self.__class__.callback_cache and \
                                 event_name in self.__class__.callback_cache[_adaptor.original_class.__name__]['before']:
                             for validator in self.__class__.callback_cache[_adaptor.original_class.__name__]['before'][event_name]:
                                 callback = validator["callback"]
                                 result = callback(self, *args, **kwargs)
-                                print("result", result)
-                                if result is not None and "parameter" in validator:
-                                    parameters_replacement[validator["parameter"]] = result
-                                print("parameters_replacement", parameters_replacement)
-
+                                if validator["result"] is not None:
+                                    additional_parameters[validator["result"]] = result
                                 if result is False:
                                     print("One of the 'before' callbacks returned false, breaking")
                                     failed = True
@@ -86,12 +83,8 @@ class BaseAdaptor(object):
                                     event_name in self.__class__.callback_cache[_adaptor.original_class.__name__]['after']:
                                 for callback in self.__class__.callback_cache[_adaptor.original_class.__name__]['after'][event_name]:
                                     if event_description is not None:
-                                        if len(parameters_replacement)==0:
-                                            print("call1", args, kwargs)
-                                            callback(self, *args, **kwargs)
-                                        else:
-                                            print("call2", parameters_replacement)
-                                            callback(self, **parameters_replacement)
+                                        callback(self, *args, **kwargs, **additional_parameters)
+                                        
 
                     return f
 
